.. _internet_domain_namespace.rst:

=========================
Internet domain namespace
=========================

Intended use of our three top level domain endings:

ploneintranet.com
    Public facing content for business audiences. High level brand experience.

ploneintranet.org
    Hosting of developer related content, documentation, non commercial community statements (licensing manifesto)

docs.ploneintranet.org
    hosting of the documentation

ploneintranet.net, *(ploneintra.net)*
    hosted project services, tracker, lists, blogs